vfbLib.parsers.bitmap.BackgroundBitmapParser
============================================

.. currentmodule:: vfbLib.parsers.bitmap

.. autoclass:: BackgroundBitmapParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BackgroundBitmapParser.__init__
      ~BackgroundBitmapParser.parse
      ~BackgroundBitmapParser.parse_bitmap_data
      ~BackgroundBitmapParser.parse_hex
      ~BackgroundBitmapParser.read_double
      ~BackgroundBitmapParser.read_doubles
      ~BackgroundBitmapParser.read_float
      ~BackgroundBitmapParser.read_floats
      ~BackgroundBitmapParser.read_int16
      ~BackgroundBitmapParser.read_int32
      ~BackgroundBitmapParser.read_int8
      ~BackgroundBitmapParser.read_str
      ~BackgroundBitmapParser.read_str_all
      ~BackgroundBitmapParser.read_uint16
      ~BackgroundBitmapParser.read_uint32
      ~BackgroundBitmapParser.read_uint8
      ~BackgroundBitmapParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BackgroundBitmapParser.encoding
      ~BackgroundBitmapParser.master_count
      ~BackgroundBitmapParser.stream
      ~BackgroundBitmapParser.ttStemsH_count
      ~BackgroundBitmapParser.ttStemsV_count
   
   